import { ref } from 'vue'

/**
 * Round-robin assignment helper for chores or other rotating duties.
 * Keeps internal pointer in reactive `index`.
 */
export function useFairness<T>() {
    const members = ref<T[]>([])
    const index = ref(0)

    function setParticipants(list: T[]) {
        members.value = list
        index.value = 0
    }

    function next(): T | undefined {
        if (members.value.length === 0) return undefined
        const member = members.value[index.value] as unknown as T
        index.value = (index.value + 1) % members.value.length
        return member
    }

    return { members, setParticipants, next }
} 