import { onMounted, onUnmounted } from 'vue'
import { useOfflineStore } from '@/stores/offline'

/**
 * Hook that wires components into the global offline queue, automatically
 * processing pending mutations when the application regains connectivity.
 */
export function useOfflineSync() {
    const offlineStore = useOfflineStore()

    const handleOnline = () => {
        offlineStore.isOnline = true
        offlineStore.processQueue()
    }
    const handleOffline = () => {
        offlineStore.isOnline = false
    }

    onMounted(() => {
        window.addEventListener('online', handleOnline)
        window.addEventListener('offline', handleOffline)
    })

    onUnmounted(() => {
        window.removeEventListener('online', handleOnline)
        window.removeEventListener('offline', handleOffline)
    })

    return {
        isOnline: offlineStore.isOnline,
        pendingActions: offlineStore.pendingActions,
        processQueue: offlineStore.processQueue,
    }
} 