import { defineStore } from 'pinia';
import { ref, computed } from 'vue';
import { groupService } from '@/services/groupService';
import type { GroupPublic as Group } from '@/types/group';

export const useGroupStore = defineStore('group', () => {
    const groups = ref<Group[]>([]);
    const isLoading = ref(false);
    const currentGroupId = ref<number | null>(null);

    const fetchUserGroups = async () => {
        isLoading.value = true;
        try {
            groups.value = await groupService.getUserGroups();
            // Set the first group as current by default if not already set
            if (!currentGroupId.value && groups.value.length > 0) {
                currentGroupId.value = groups.value[0].id;
            }
        } catch (error) {
            console.error('Failed to fetch groups:', error);
        } finally {
            isLoading.value = false;
        }
    };

    const setCurrentGroupId = (id: number) => {
        currentGroupId.value = id;
    };

    const currentGroup = computed(() => {
        if (!currentGroupId.value) return null;
        return groups.value.find(g => g.id === currentGroupId.value);
    });

    const groupCount = computed(() => groups.value.length);
    const firstGroupId = computed(() => groups.value[0]?.id ?? null);

    // Alias for backward compatibility
    const fetchGroups = fetchUserGroups;

    return {
        groups,
        isLoading,
        currentGroupId,
        currentGroup,
        fetchUserGroups,
        fetchGroups,
        setCurrentGroupId,
        groupCount,
        firstGroupId,
    };
}); 